<?php
/**
 * Default theme options.
 *
 * @package Creativ Agency
 */

if ( ! function_exists( 'creativ_agency_get_default_theme_options' ) ) :

	/**
	 * Get default theme options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Default theme options.
	 */
function creativ_agency_get_default_theme_options() {

	$defaults = array();

	// Top Bar
	$defaults['show_header_contact_info'] 	= true;
    $defaults['header_email']             	= __( 'info@creativthemes.com','creativ-agency' );
    $defaults['header_phone' ]            	= __( '8801 234 567 890','creativ-agency' );
    $defaults['header_location' ]           = __( 'Labartisan 1205 Dhaka','creativ-agency' );
    $defaults['show_header_social_links'] 	= true;
    $defaults['header_social_links']		= array();

	// Featured Slider Section
	$defaults['disable_featured_slider']	= true;
	$defaults['number_of_sr_items']			= 3;
	$defaults['featured_slider_overlay']	= 0.8;
	$defaults['sr_content_type']			= 'sr_page';

	// Our Services Section
	$defaults['disable_our_services_section']	= true;
	$defaults['our_services_section_icon']		= esc_html__( 'fas fa-magic', 'creativ-agency' );
	$defaults['our_services_section_title']		= esc_html__( 'Our Services', 'creativ-agency' );
	$defaults['our_services_section_subtitle']	= esc_html__( 'It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout.', 'creativ-agency' );
	$defaults['number_of_column']				= 3;
	$defaults['number_of_items']				= 3;
	$defaults['ad_content_type']				= 'ad_page';

	//Call To Action Section	
	$defaults['disable_cta_section']	   	= true;
	$defaults['background_cta_section']		= get_template_directory_uri() .'/assets/images/default-header.jpg';
	$defaults['cta_small_description']	   	= esc_html__( 'It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout.', 'creativ-agency' );
	$defaults['cta_description']	   	 	= esc_html__( 'Become a part of Creativ Agency community today.', 'creativ-agency' );
	$defaults['cta_overlay']				= 0.85;
	$defaults['cta_button_label']	   	 	= esc_html__( 'Contact Us', 'creativ-agency' );
	$defaults['cta_button_url']	   	 		= '#';

	// Our Features Section
	$defaults['disable_features_section']		= true;
	$defaults['features_section_icon']			= esc_html__( 'fa fa-list-ul', 'creativ-agency' );
	$defaults['features_section_title']			= esc_html__( 'Some Of Features', 'creativ-agency' );
	$defaults['features_section_subtitle']		= esc_html__( 'It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout.', 'creativ-agency' );
	$defaults['number_of_features_items']		= 3;
	$defaults['features_content_type']			= 'features_page';

	//Faq Section	
	$defaults['disable_faq_section']		= true;
	$defaults['faq_section_icon']			= esc_html__( 'fas fa-question', 'creativ-agency' );
	$defaults['faq_section_title']			= esc_html__( 'Our faq', 'creativ-agency' );
	$defaults['faq_section_subtitle']		= esc_html__( 'It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout.', 'creativ-agency' );
	$defaults['number_of_cs_column']		= 2;
	$defaults['number_of_cs_items']			= 6;
	$defaults['cs_content_type']			= 'cs_page';

	// Blog Section
	$defaults['disable_blog_section']		= true;
	$defaults['blog_section_icon']			= esc_html__( 'fas fa-bookmark', 'creativ-agency' );
	$defaults['blog_section_title']			= esc_html__( 'Our Latest Post', 'creativ-agency' );
	$defaults['blog_section_subtitle']		= esc_html__( 'It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout.', 'creativ-agency' );
	$defaults['blog_category']	   			= 0; 
	$defaults['blog_number']				= 3;	

	//General Section
	$defaults['readmore_text']					= esc_html__('Read More','creativ-agency');
	$defaults['your_latest_posts_title']		= esc_html__('Blog','creativ-agency');
	$defaults['excerpt_length']					= 25;
	$defaults['layout_options_blog']			= 'right-sidebar';
	$defaults['layout_options_archive']			= 'right-sidebar';
	$defaults['layout_options_page']			= 'right-sidebar';	
	$defaults['layout_options_single']			= 'right-sidebar';	

	//Footer section 		
	$defaults['copyright_text']					= esc_html__( 'Copyright &copy; All rights reserved.', 'creativ-agency' );

	// Pass through filter.
	$defaults = apply_filters( 'creativ_agency_filter_default_theme_options', $defaults );
	return $defaults;
}

endif;

/**
*  Get theme options
*/
if ( ! function_exists( 'creativ_agency_get_option' ) ) :

	/**
	 * Get theme option
	 *
	 * @since 1.0.0
	 *
	 * @param string $key Option key.
	 * @return mixed Option value.
	 */
	function creativ_agency_get_option( $key ) {

		$default_options = creativ_agency_get_default_theme_options();
		if ( empty( $key ) ) {
			return;
		}

		$theme_options = (array)get_theme_mod( 'theme_options' );
		$theme_options = wp_parse_args( $theme_options, $default_options );

		$value = null;

		if ( isset( $theme_options[ $key ] ) ) {
			$value = $theme_options[ $key ];
		}

		return $value;

	}

endif;