<?php
/**
 * faq options.
 *
 * @package Creativ Agency Pro
 */

$default = creativ_agency_get_default_theme_options();

// Featured faq Section
$wp_customize->add_section( 'section_faq',
	array(
		'title'      => __( 'Our Faq', 'creativ-agency' ),
		'priority'   => 100,
		'capability' => 'edit_theme_options',
		'panel'      => 'home_page_panel',
		)
);
// Disable faq Section
$wp_customize->add_setting('theme_options[disable_faq_section]', 
	array(
	'default' 			=> $default['disable_faq_section'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'creativ_agency_sanitize_checkbox'
	)
);

$wp_customize->add_control('theme_options[disable_faq_section]', 
	array(		
	'label' 	=> __('Disable faq Section', 'creativ-agency'),
	'section' 	=> 'section_faq',
	'settings'  => 'theme_options[disable_faq_section]',
	'type' 		=> 'checkbox',	
	)
);

// Section Icon
$wp_customize->add_setting('theme_options[faq_section_icon]', 
	array(
	'default'           => $default['faq_section_icon'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'sanitize_text_field'
	)
);

$wp_customize->add_control('theme_options[faq_section_icon]', 
	array(
	'label'       => __('Section Icon', 'creativ-agency'),

	'description' => sprintf( __('Please input icon as eg: fab fa-buffer. Find Font Aawesome icons %1$shere%2$s', 'creativ-agency'), '<a href="' . esc_url( 'https://fontawesome.com/icons' ) . '" target="_blank">', '</a>' ),
	'section'     => 'section_faq',   
	'settings'    => 'theme_options[faq_section_icon]',	
	'active_callback' => 'creativ_agency_faq_active',		
	'type'        => 'text'
	)
);

// Section Title
$wp_customize->add_setting('theme_options[faq_section_title]', 
	array(
	'default'           => $default['faq_section_title'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'sanitize_text_field'
	)
);

$wp_customize->add_control('theme_options[faq_section_title]', 
	array(
	'label'       => __('Section Title', 'creativ-agency'),
	'section'     => 'section_faq',   
	'settings'    => 'theme_options[faq_section_title]',	
	'active_callback' => 'creativ_agency_faq_active',		
	'type'        => 'text'
	)
);

// Section Sub Title
$wp_customize->add_setting('theme_options[faq_section_subtitle]', 
	array(
	'default'           => $default['faq_section_subtitle'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'sanitize_text_field'
	)
);

$wp_customize->add_control('theme_options[faq_section_subtitle]', 
	array(
	'label'       => __('Section Sub Title', 'creativ-agency'),
	'section'     => 'section_faq',   
	'settings'    => 'theme_options[faq_section_subtitle]',	
	'active_callback' => 'creativ_agency_faq_active',		
	'type'        => 'text'
	)
);

// Number of Items
$wp_customize->add_setting('theme_options[number_of_cs_column]', 
	array(
	'default' 			=> $default['number_of_cs_column'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'creativ_agency_sanitize_number_range'
	)
);

$wp_customize->add_control('theme_options[number_of_cs_column]', 
	array(
	'label'       => __('Column Per Row', 'creativ-agency'),
	'description' => __('Save & Refresh the customizer to see its effect. Maximum is 2', 'creativ-agency'),
	'section'     => 'section_faq',   
	'settings'    => 'theme_options[number_of_cs_column]',		
	'type'        => 'number',
	'active_callback' => 'creativ_agency_faq_active',
	'input_attrs' => array(
			'min'	=> 1,
			'max'	=> 2,
			'step'	=> 1,
		),
	)
);
// Number of items
$wp_customize->add_setting('theme_options[number_of_cs_items]', 
	array(
	'default' 			=> $default['number_of_cs_items'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'creativ_agency_sanitize_number_range'
	)
);

$wp_customize->add_control('theme_options[number_of_cs_items]', 
	array(
	'label'       => __('Number Of Items', 'creativ-agency'),
	'description' => __('Save & Refresh the customizer to see its effect. Maximum is 6.', 'creativ-agency'),
	'section'     => 'section_faq',   
	'settings'    => 'theme_options[number_of_cs_items]',		
	'type'        => 'number',
	'active_callback' => 'creativ_agency_faq_active',
	'input_attrs' => array(
			'min'	=> 1,
			'max'	=> 6,
			'step'	=> 1,
		),
	)
);

$wp_customize->add_setting('theme_options[cs_content_type]', 
	array(
	'default' 			=> $default['cs_content_type'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'creativ_agency_sanitize_select'
	)
);

$wp_customize->add_control('theme_options[cs_content_type]', 
	array(
	'label'       => __('Content Type', 'creativ-agency'),
	'section'     => 'section_faq',   
	'settings'    => 'theme_options[cs_content_type]',		
	'type'        => 'select',
	'active_callback' => 'creativ_agency_faq_active',
	'choices'	  => array(
			'cs_page'	  => __('Page','creativ-agency'),
			'cs_post'	  => __('Post','creativ-agency'),
		),
	)
);

$number_of_cs_items = creativ_agency_get_option( 'number_of_cs_items' );

for( $i=1; $i<=$number_of_cs_items; $i++ ){

	// Page
	$wp_customize->add_setting('theme_options[faq_page_'.$i.']', 
		array(
		'type'              => 'theme_mod',
		'capability'        => 'edit_theme_options',	
		'sanitize_callback' => 'creativ_agency_dropdown_pages'
		)
	);

	$wp_customize->add_control('theme_options[faq_page_'.$i.']', 
		array(
		'label'       => __('Select Page', 'creativ-agency'),
		'section'     => 'section_faq',   
		'settings'    => 'theme_options[faq_page_'.$i.']',		
		'type'        => 'dropdown-pages',
		'active_callback' => 'creativ_agency_faq_page',
		)
	);

	// Posts
	$wp_customize->add_setting('theme_options[faq_post_'.$i.']', 
		array(
		'type'              => 'theme_mod',
		'capability'        => 'edit_theme_options',	
		'sanitize_callback' => 'creativ_agency_dropdown_pages'
		)
	);

	$wp_customize->add_control('theme_options[faq_post_'.$i.']', 
		array(
		'label'       => sprintf( __('Select Post #%1$s', 'creativ-agency'), $i),
		'section'     => 'section_faq',   
		'settings'    => 'theme_options[faq_post_'.$i.']',		
		'type'        => 'select',
		'choices'	  => creativ_agency_dropdown_posts(),
		'active_callback' => 'creativ_agency_faq_post',
		)
	);
}
